# Slot: local name


the nsname (sans ':' for a given prefix)

URI: [http://w3id.org/biolink/biolinkml/meta/local_name](slot_uri)
## Domain and Range

[Prefix](Prefix.md) -> [Ncname](Ncname.md)
## Inheritance

## Children

## Used by

 * [Prefix](Prefix.md)
